from fintekkers.models.transaction.transaction_type_pb2 import TransactionTypeProto

class TransactionType():
    def __init__(self, proto: TransactionTypeProto):
        self.proto = proto

    def __str__(self) -> str:
        return TransactionTypeProto.Name(self.proto)




from fintekkers.wrappers.models.util import uuid

def test_conversion():
    tmp_uuid = uuid.FintekkersUuid.new_uuid()

    uuid_as_str = tmp_uuid.__str__()

    uuid_from_bytes_as_str = uuid.FintekkersUuid.from_bytes(tmp_uuid.uuid.bytes).__str__()
    
    assert uuid_as_str.__str__() == uuid_from_bytes_as_str.__str__()

    uuid_from_uuid = uuid.FintekkersUuid.from_uuid(tmp_uuid.uuid).__str__()

    assert uuid_from_uuid.__str__() == uuid_from_bytes_as_str.__str__()
    
    


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/requests/position/query_position_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.position import position_pb2 as fintekkers_dot_models_dot_position_dot_position__pb2
from fintekkers.requests.position import query_position_request_pb2 as fintekkers_dot_requests_dot_position_dot_query__position__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:fintekkers/requests/position/query_position_response.proto\x12\x1c\x66intekkers.requests.position\x1a)fintekkers/models/position/position.proto\x1a\x39\x66intekkers/requests/position/query_position_request.proto\"\xf0\x01\n\x1aQueryPositionResponseProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12Q\n\x10position_request\x18\x0b \x01(\x0b\x32\x37.fintekkers.requests.position.QueryPositionRequestProto\x12\x1a\n\x12reporting_currency\x18\x0c \x01(\t\x12<\n\tpositions\x18\x1e \x03(\x0b\x32).fintekkers.models.position.PositionProtoB\x1f\x42\x1bQueryPositionResponseProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.position.query_position_response_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\033QueryPositionResponseProtosP\001'
  _QUERYPOSITIONRESPONSEPROTO._serialized_start=195
  _QUERYPOSITIONRESPONSEPROTO._serialized_end=435
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/requests/security/create_security_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.security import security_pb2 as fintekkers_dot_models_dot_security_dot_security__pb2
from fintekkers.requests.security import create_security_request_pb2 as fintekkers_dot_requests_dot_security_dot_create__security__request__pb2
from fintekkers.requests.util.errors import summary_pb2 as fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;fintekkers/requests/security/create_security_response.proto\x12\x1c\x66intekkers.requests.security\x1a)fintekkers/models/security/security.proto\x1a:fintekkers/requests/security/create_security_request.proto\x1a-fintekkers/requests/util/errors/summary.proto\"\xa9\x02\n\x1b\x43reateSecurityResponseProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12R\n\x10security_request\x18\x14 \x01(\x0b\x32\x38.fintekkers.requests.security.CreateSecurityRequestProto\x12\x44\n\x11security_response\x18\x1e \x01(\x0b\x32).fintekkers.models.security.SecurityProto\x12I\n\x12\x65rrors_or_warnings\x18( \x01(\x0b\x32-.fintekkers.requests.util.errors.SummaryProtoB B\x1c\x43reateSecurityResponseProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.security.create_security_response_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\034CreateSecurityResponseProtosP\001'
  _CREATESECURITYRESPONSEPROTO._serialized_start=244
  _CREATESECURITYRESPONSEPROTO._serialized_end=541
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/models/portfolio/portfolio.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.util import local_timestamp_pb2 as fintekkers_dot_models_dot_util_dot_local__timestamp__pb2
from fintekkers.models.util import uuid_pb2 as fintekkers_dot_models_dot_util_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+fintekkers/models/portfolio/portfolio.proto\x12\x1b\x66intekkers.models.portfolio\x1a,fintekkers/models/util/local_timestamp.proto\x1a!fintekkers/models/util/uuid.proto\"\xcd\x01\n\x0ePortfolioProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12/\n\x04uuid\x18\x05 \x01(\x0b\x32!.fintekkers.models.util.UUIDProto\x12:\n\x05\x61s_of\x18\x06 \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProto\x12\x0f\n\x07is_link\x18\x07 \x01(\x08\x12\x16\n\x0eportfolio_name\x18\n \x01(\tB\x13\x42\x0fPortfolioProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.portfolio.portfolio_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\017PortfolioProtosP\001'
  _PORTFOLIOPROTO._serialized_start=158
  _PORTFOLIOPROTO._serialized_end=363
# @@protoc_insertion_point(module_scope)
